// -*-C++-*-
//
// File:      DalSelectionView.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Mon Aug  7 15:53:00 MET DST 2000

#include "DalSelectionView.h"
#include "DalListViewItem.h"

#include <qlistview.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qtooltip.h>

#include <iostream>

DalSelectionView::DalSelectionView(QWidget* parent, const char* name) : 
  QWidget(parent,name),_multi(true)
{
  _counter=0;

  _list = new QListView(this);
  _list->addColumn("Selection");
  //_list->addColumn("Order");
  _list->setSorting(-1);
  _list->setMultiSelection(true);

  _clear=new QPushButton("Clear All",this);
  _clear->setEnabled(false);
  _delete=new QPushButton("Remove",this);
  _delete->setEnabled(false);

  QVBoxLayout* vbox=new QVBoxLayout(this,0);
  vbox->addWidget(_list);
  QHBoxLayout* hbox=new QHBoxLayout(vbox,5);
  hbox->addStretch(1);
  hbox->addWidget(_clear);
  hbox->addWidget(_delete);

  QToolTip::add(_list,"This pane shows all items added by the User");
  QToolTip::add(_clear,"Remove all items");
  QToolTip::add(_delete,"Remove selected items only");

  
  connect(_clear,SIGNAL(clicked()),this,SLOT(clear()));
  connect(_delete,SIGNAL(clicked()),this,SLOT(remove()));
  connect(_list,SIGNAL(selectionChanged()),
	  this,SLOT(changedSelection()));
  
  setCaption("Selected Data items");
}

DalSelectionView::~DalSelectionView()
{
}

void DalSelectionView::add(DalListViewItem* d)
{
  if (!d) return;

  QString txt(d->qualifiedName());
  QListViewItem* item = _list->firstChild();
  QListViewItem* last=item;
  while(item) {
    if (item->text(0) == txt) return;
    last = item;
    item = item->nextSibling();
  }
  if (!_multi) {
    blockSignals(true);
    clear();
    blockSignals(false);
  }

  // not found, so:
  item=new QListViewItem(_list,last);
  item->setText(0,txt);
  const QPixmap* pix=d->pixmap(0);
  if (pix) item->setPixmap(0,*pix);
  //item->setText(1,QString::number(_counter++));

  _clear->setEnabled(true);
  emit filled(true);
}

void DalSelectionView::clear()
{
  _list->clear();
  _counter=0;
  _clear->setEnabled(false);
  _delete->setEnabled(false);
  emit filled(false);
}

void DalSelectionView::remove()
{
  bool enabled=true;
  QListViewItem* item=_list->firstChild();
  while (item) {
    QListViewItem* next=item->nextSibling();
    if (item->isSelected()) {
      delete item;
      enabled=false;
    }
    item=next;
  }
  _delete->setEnabled(enabled);
  if (!_list->childCount()) clear();
}


void DalSelectionView::changedSelection()
{
  QListViewItem* item=_list->firstChild();
  while (item) {
    if (item->isSelected()) {
      _delete->setEnabled(true);
      break;
    }
    item=item->nextSibling();
  }
}

QStringList DalSelectionView::selection()
{
  QStringList list;
  QListViewItem* item=_list->firstChild();
  while (item) {
    list+=item->text(0);
    item=item->nextSibling();
  }
  return list;
}

void DalSelectionView::pop()
{
  if (isVisible()) hide();
  else show();
}

void DalSelectionView::setMultiSelection(bool b)
{
  _multi=b;
  if (b) show();
}
