// -*-C++-*-
//
// File:      DalViewArrayContents.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Mon Jul 31 12:42:43 MET DST 2000

#include "DalViewArrayContents.h"
#include <Dal.h>

#include <qimage.h>
#include <qpixmap.h>


class DalArrayCanvas : public QWidget
{
public:
  DalArrayCanvas(QWidget* parent, const char* name) : 
    QWidget(parent,name),_view(0)
    {
      setFixedSize(0,0);
    }
  ~DalArrayCanvas()
    {
      delete _view;
    }

  void createImage(Array* array)
    {
      if (_view) return;
      _view=new QPixmap;

      if (!array) return;
      int x=(array->size())[0];
      int y=(array->size())[1];
      
      ArrayData* data=0;
      switch (array->dataType())
	{
	case Dal::Bool:
	  break;
	case Dal::Int8:
	  data=array->data();
	  createImage(x,y,data->int8Data());
	  break;
	case Dal::Int16:
	  data=array->data();
	  createImage(x,y,data->int16Data());
	  break;
	case Dal::Uint16:
	  data=array->data();
	  createImage(x,y,data->uint16Data());
	  break;
	case Dal::Int32:
	  data=array->data();
	  createImage(x,y,data->int32Data());
	  break;
	case Dal::Uint32:
	  data=array->data();
	  createImage(x,y,data->uint32Data());
	  break;
	case Dal::Real32:
	  data=array->data();
	  createImage(x,y,data->real32Data());
	  break;
	case Dal::Real64:
	  data=array->data();
	  createImage(x,y,data->real64Data());
	  break;
	case Dal::DString:
	  break;
	}
      delete data;

      if (_view) setFixedSize(_view->size());
      update();
    }

  void createImage(int m,int n,int8* ptr)
    {
      QImage im(m,n,32); // 32-bits depth      
      for (int x=0;x<m;x++) {
	for (int y=0;y<n;y++) {
	  im.setPixel(x,y,(*ptr));
	  ptr++;
	}
      }
      _view->convertFromImage(im);
    }
  void createImage(int m,int n,int16* ptr)
    {
      QImage im(m,n,32); // 32-bits depth      
      for (int x=0;x<m;x++) {
	for (int y=0;y<n;y++) {
	  im.setPixel(x,y,(*ptr));
	  ptr++;
	}
      }
      _view->convertFromImage(im);
    }
  void createImage(int m,int n,uint16* ptr)
    {
      QImage im(m,n,32); // 32-bits depth      
      for (int x=0;x<m;x++) {
	for (int y=0;y<n;y++) {
	  im.setPixel(x,y,(*ptr));
	  ptr++;
	}
      }
      _view->convertFromImage(im);
    }
  void createImage(int m,int n,int32* ptr)
    {
      QImage im(m,n,32); // 32-bits depth      
      for (int x=0;x<m;x++) {
	for (int y=0;y<n;y++) {
	  im.setPixel(x,y,(*ptr));
	  ptr++;
	}
      }
      _view->convertFromImage(im);
    }
  void createImage(int m,int n,uint32* ptr)
    {
      QImage im(m,n,32); // 32-bits depth      
      for (int x=0;x<m;x++) {
	for (int y=0;y<n;y++) {
	  im.setPixel(x,y,(*ptr));
	  ptr++;
	}
      }
      _view->convertFromImage(im);
    }
  void createImage(int m,int n,real32* ptr)
    {
      QImage im(m,n,32); // 32-bits depth      
      for (int x=0;x<m;x++) {
	for (int y=0;y<n;y++) {
	  im.setPixel(x,y,(unsigned int)(*ptr));
	  ptr++;
	}
      }
      _view->convertFromImage(im);
    }
  void createImage(int m,int n,real64* ptr)
    {
      QImage im(m,n,32); // 32-bits depth      
      for (int x=0;x<m;x++) {
	for (int y=0;y<n;y++) {
	  im.setPixel(x,y,(unsigned int)(*ptr));
	  ptr++;
	}
      }
      _view->convertFromImage(im);
    }

  void paintEvent(QPaintEvent* e) {
    if (_view) bitBlt(this, 0, 0, _view);
    else QWidget::paintEvent(e);
  }
private:
  QPixmap* _view;
  bool     _done;
};


//----------------------------------------------------------------------------
DalViewArrayContents::DalViewArrayContents(Array* array,
				   QWidget* parent, const char* name) : 
  QScrollView(parent,name),_array(array)
{
  _canvas=new DalArrayCanvas(viewport(),"ImageViewer");
  addChild(_canvas);
}

DalViewArrayContents::~DalViewArrayContents()
{
}


void DalViewArrayContents::showData()
{

  _canvas->createImage(_array);
}
