// -*-C++-*-
//
// File:      DalViewColumnContents.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Mon Jul 31 12:42:43 MET DST 2000

#include "DalViewColumnContents.h"
#include <Dal.h>


DalViewColumnContents::DalViewColumnContents(Column* column,
				   QWidget* parent, const char* name) : 
  QTable(parent,name),
  _column(column),
  _done(false)
{
  //setReadOnly(true);
  setNumRows(1);
  setNumCols(1);
  setText(0,0,"<contents not loaded>");
}

DalViewColumnContents::~DalViewColumnContents()
{
}

void DalViewColumnContents::showData()
{
  if (_done) return;
  unsigned nrows = _column->rows();
  unsigned ncols = numCols();
  setNumRows(nrows);

  Dal::DataType dataType=_column->dataType();

  for (unsigned row=0;row<nrows;row++) {
    ColumnData * colData=_column->rowData(row,Dal::Read); // may be 1 cell
    unsigned cells=colData->elements();
    if (cells>ncols) {
      ncols=cells;
      setNumCols(ncols);
    }

    for (unsigned col=0;col<cells;col++) {
      switch(dataType)
	{
	case Dal::Bool: {
	  bool8* data = colData->boolData();
	  setText(row,col,QString().setNum(data[col]));
	  break;
	}
	case Dal::Int8: {
	  int8* data = colData->int8Data();
	  setText(row,col,QString().setNum((int)data[col]));
	  break;
	}
	case Dal::Int16: {
	  int16* data = colData->int16Data();
	  setText(row,col,QString().setNum(data[col]));
	  break;
	}
	case Dal::Uint16: {
	  uint16* data = colData->uint16Data();
	  setText(row,col,QString().setNum(data[col]));
	  break;
	}
	case Dal::Int32: {
	  int32* data = colData->int32Data();
	  setText(row,col,QString().setNum(data[col]));
	  break;
	}
	case Dal::Uint32: {
	  uint32* data = colData->uint32Data();
	  setText(row,col,QString().setNum(data[col]));
	  break;
	}
	case Dal::Real32: {
	  real32* data = colData->real32Data();
	  setText(row,col,QString().setNum(data[col]));
	  break;
	}
	case Dal::Real64: {
	  real64* data = colData->real64Data();
	  setText(row,col,QString().setNum(data[col]));
	  break;
	}
	case Dal::DString: {
	  char* data = colData->stringData();
	  setText(row,col,QString().setNum(data[col]));
	  break;
	}
	}
    }
    delete colData;
  }
  
  for (unsigned col=0;col<ncols;col++) adjustColumn(col);
  _done=true;
}

/*
void DalViewColumnContents::showData()
{
  if (_done) return;
  clear();
  ColumnData* d = _column->data();
  unsigned nrows = _column->rows();

  // Display the data, according to type
  switch(_column->dataType())
    {
    case Dal::Bool: {
      bool8* data = d->boolData();
      for(unsigned k=0; k<nrows; k++)
	{
	  append(QString().setNum(k) + "\t" + 
		 QString().setNum(data[k]));
	}
      break;
    }
    case Dal::Int8: {
      int8* data = d->int8Data();
      for(unsigned k=0; k<nrows; k++)
	{
	  append(QString().setNum(k) + "\t" + 
		 QString().setNum((int)data[k]));
	}
      break;
    }
    case Dal::Int16: {
      int16* data = d->int16Data();
      for(unsigned k=0; k<nrows; k++)
	{
	  append(QString().setNum(k) + "\t" + 
		 QString().setNum(data[k]));
	}
	    break;
    }
    case Dal::Int32: {
      int32* data = d->int32Data();
      for(unsigned k=0; k<nrows; k++)
	    {	
	      append(QString().setNum(k) + "\t" + 
		     QString().setNum(data[k]));
 	    }
      break;
    }
    case Dal::Real32: {
      real32* data = d->real32Data();
      for(unsigned k=0; k<nrows; k++)
	{
	  append(QString().setNum(k) + "\t" + 
		     QString().setNum(data[k]));
	}
      break;
    }
    case Dal::Real64: {
      real64* data = d->real64Data();
      for(unsigned k=0; k<nrows; k++)
	{
	  append(QString().setNum(k) + "\t" + 
		 QString().setNum(data[k]));
	}
      break;
    }
    case Dal::DString: {
      //char* data = d->stringData();
      // uint size = d->elements();
      
  	    for(unsigned k=0; k<nrows; k++)
	      {
		append(QString().setNum(k) + "\t" + 
		       QString("NOT IMPLEMENTED!"));
		//QString(data + k*size, size));
	      }
	    break;
    }
    case Dal::Uint16: {
      uint16* data = d->uint16Data();
      for(unsigned k=0; k<nrows; k++)
	{
	  append(QString().setNum(k) + "\t" + 
		 QString().setNum(data[k]));
	}
      break;
    }
    case Dal::Uint32: {
      uint32* data = d->uint32Data();
      for(unsigned k=0; k<nrows; k++)
	{
	  append(QString().setNum(k) + "\t" + 
		 QString().setNum(data[k]));
	}
      break;
    }
    }
  delete d;
  _done=true;
}
*/
