// -*-C++-*-
//
// File:      Folder.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Tue Jul 25 13:40:55 MET DST 2000

#include "Folder.h"
#include <Dal.h>

#include <qdir.h>
#include <qfile.h>
#include <qfileinfo.h>

#include <fstream>
#include <iostream>

Folder::Folder(const QString& name,Folder* parent) :
  _parsed(false),_readable(false),_name(name),_parent(parent)
{
  _folders.setAutoDelete(true);
  _files.setAutoDelete(true);
  _readable=QDir(QDir::cleanDirPath(qualifiedName())).isReadable();
}

Folder::~Folder()
{
}

void Folder::parse()
{
  if (_parsed) return;
  _parsed=true;

  if (!_readable) return;

  QDir thisDir( QDir::cleanDirPath(qualifiedName()));
  /*
  std::cerr << "parse:" << thisDir.absPath() << std::endl;
  */
  const QFileInfoList * entries = thisDir.entryInfoList();
  if ( !entries ) return;

  QFileInfoListIterator it( *entries);
  QFileInfo * entry;
  while( (entry=it.current()) != 0 ) {
    ++it;
    if ( entry->fileName() == "." || entry->fileName() == ".." )
      ; // nothing
    else if ( entry->isDir() ) {
      /*
      std::cerr << " dir:" << entry->fileName() << std::endl;
      */
      _folders.append(new Folder(entry->fileName(), this));
    }
    else {
      QString file(qualifiedName());
      file.append( "/" );
      file.append( entry->fileName() );
      
      _files.append(new AnyFile(entry->fileName(),this));   
    }
  }
}

QString Folder::qualifiedName()
{
  QString s;
  if ( _parent ) {
    s = _parent->qualifiedName();
    s.append( "/" );
    s.append( _name );

    s=QDir::cleanDirPath(s);
  } else {
    s = _name;
  }
  return s;
}


//Check if there are new files in the directory or 
//if files have been removed. The file list is updated.
void Folder::updateFiles()
{
  
  QDir thisDir( QDir::cleanDirPath(qualifiedName()));
  const QFileInfoList * entries = thisDir.entryInfoList();

  if ( !entries ) return;

  QFileInfoListIterator it( *entries);
  QFileInfo * entry;
  
  //Create a new files with all the files in the directory
  while( (entry=it.current()) != 0 ) {
    ++it;
    if ( entry->fileName() == "." || entry->fileName() == ".." )
      ; // nothing
    else if ( entry->isDir() ) {
      ; //nothing
    }
    else {
      QString file(qualifiedName());
      file.append( "/" );
      file.append( entry->fileName() );
      _filesRefresh.append(new AnyFile(entry->fileName(),this)); 
    }    
  }
  
  _files.first();
  _filesRefresh.first();
  //Add the new files to the _files list
  if (_filesRefresh.count() >= _files.count() )
    {
      if (_files.count() != _filesRefresh.count()) {  
	for (uint i = 0; i <_filesRefresh.count(); i++ )
	  {
	    if ( i == _files.count() ) {
	      _files.insert ( i, _filesRefresh.current() );   	      
	      if(i !=_files.count()) 
		_files.next();
	      if (i != _filesRefresh.count())
		_filesRefresh.next();
	    } else if ( _files.current()->qualifiedName() == _filesRefresh.current()->qualifiedName() ) {
	      _filesRefresh.next();
	      _files.next();  
	    }
	    else {
	      _files.insert ( i, _filesRefresh.current() );   	      
	      if(i !=_files.count()) 
		_files.next();
	      if (i != _filesRefresh.count())
		_filesRefresh.next();
	    }
	  }	
      }      
    } 
  
  //Remove the files from the _files list.
  //There are problems with the DataSet that has been openned
  //and removed. The pointer from the folder to the Dataset file
  //fails.

  /*
  else {
    int i = 0;
    int counterRefresh = 0;
    int counterRemove = 0;

    if (_filesRefresh.isEmpty() ) {
      _files.clear();
    } else {
      while ( _files.count() != _filesRefresh.count() )
	{
	  
	  if ( counterRefresh == int(_filesRefresh.count()) ) {
	    _filesRefresh.last();
	    if ( _files.current()->qualifiedName() == _filesRefresh.current()->qualifiedName() ) {
	      _files.next();
	    } else { 	      
	      _files.remove();
	      counterRemove++;
	    }
	  } else if ( _files.current()->qualifiedName() == _filesRefresh.current()->qualifiedName() ) {
	    _files.next(); 
	    if(int (_filesRefresh.count() ) == counterRefresh ) {
	      ;
	    } else {	   
	      _filesRefresh.next();
	      counterRefresh++;
	    }
	  }
	  else {
	    _files.remove();
	    counterRemove++;
	  }	
	  i++;
	}
    }
  }
  */
  
  
  _filesRefresh.clear();

}
