// -*-C++-*-
//
// File:      AngleParamWidget.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Fri May  3 15:54:07 MEST 2002

#include "AngleParamWidget.h"
#include "FormattedAngleParamWidget.h"
#include "AngleParameter.h"

#include <qlayout.h>               // Qt headers
#include <qcombobox.h>

AngleParamWidget::AngleParamWidget(AngleParameter* par,QWidget* parent, const char* name) : QWidget(parent,name)
{
  _text=new FormattedAngleParamWidget(par,this);
  par->addView(this);

  _mode = new QComboBox(false,this,"AngleMode");
  _mode->insertItem("deg",0);
  _mode->insertItem("DMS",1);
  _mode->insertItem("HMS",2);

  // layout
  QHBoxLayout* box = new QHBoxLayout(this,0,-1,"AngleParamWidgetLayout");
  box->addWidget(_text);
  box->addWidget(_mode);
  box->addStretch(1);

  // update parameter representation
  updateView();
  
  // signal-slots
  connect(_mode,SIGNAL(activated(int)),
	  this,SLOT(activateMode(int)));

}

AngleParamWidget::~AngleParamWidget()
{
  _text->parameter()->deleteView(this);
}

/* triggered by changes in combo box */
void AngleParamWidget::activateMode(int id)
{
  AngleFormatter::AngleMode m = AngleFormatter::Degrees;

  switch (id) {
  case 0: m = AngleFormatter::Degrees ; break;
  case 1: m = AngleFormatter::DMS     ; break;
  case 2: m = AngleFormatter::HMS     ; break;
  default: break;
  }
  ((AngleParameter*)(_text->parameter()))->setMode(m);
}

/* transmit changes in the mode to combo box */
void AngleParamWidget::updateView()
{
  AngleFormatter::AngleMode m=
    ((AngleParameter*)(_text->parameter()))->getMode();

  int id=_mode->currentItem();
  switch(m) {
  case AngleFormatter::Degrees: id=0; break;
  case AngleFormatter::DMS:     id=1; break;
  case AngleFormatter::HMS:     id=2; break;
  default: break;
  }
  
  _mode->setCurrentItem(id);
}
