/*****************************************************************************
 *
 *  BoolParamWidget.cc                          XMM Science Analysis Subsystem
 *
 *  Widget for editting boolean parameters
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: BoolParamWidget.cc,v 1.8 2004/02/05 18:40:27 aibarra Exp $
 *
 *****************************************************************************/

#include "BoolParamWidget.h" // Application headers
#include "Parameter.h"
#include "BoolParameter.h"

#include <iostream>        // C++ headers
#include <string>

#include <qcheckbox.h>       // Qt headers
#include <qtooltip.h>


//================================================================
//  Class BoolParamWidget
//================================================================

BoolParamWidget::BoolParamWidget(BoolParameter* par, QWidget* parent, 
				 const char* label)
  : QCheckBox(label,parent)
{
    _par = par;
    _par->addView(this);
    string prompt = _par->prompt();

    if(prompt.length()>0)
        QToolTip::add(this,prompt.c_str());
    connect(this, SIGNAL(toggled(bool)), this, SLOT(valueChanged(bool)));

    updateView();
}

BoolParamWidget::~BoolParamWidget()
{
    _par->deleteView(this);
}

void BoolParamWidget::valueChanged(bool value)
{
    _par->setValue(value);
}

void BoolParamWidget::updateView()
{
    setChecked(_par->boolValue());
}

