/*****************************************************************************
 *
 *  ChoiceParamWidget.cc                  XMM Science Analysis Subsystem
 *
 *  Widget for selecting from a set of strings
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: ChoiceParamWidget.cc,v 1.1 2002/05/21 16:39:42 jbakker Exp $
 *
 *****************************************************************************/

#include "ChoiceParamWidget.h"  // Application headers
#include "Parameter.h"

#include <iostream>                 // C++ headers
#include <string>
#include <qcombobox.h>

#include <qtooltip.h>                 // Qt headers


//================================================================
//  Class ChoiceParamWidget
//================================================================

ChoiceParamWidget::ChoiceParamWidget(Parameter* par,
				     QWidget* parent)
  : QComboBox(parent)
{
    _par = par;
    _par->addView(this);
    string prompt = _par->prompt();
    const list<string> choices = _par->choices();

    // Add each choice to the menu
    list<string>::const_iterator it = choices.begin();
    while(it != choices.end())
        insertItem((*it++).c_str());

    if(prompt.length()>0)
        QToolTip::add(this,prompt.c_str());

    connect(this, SIGNAL(activated(const QString&)), 
 	    this, SLOT(valueChanged(const QString&)));

    updateView();
}

ChoiceParamWidget::~ChoiceParamWidget()
{
    _par->deleteView(this);
}

void ChoiceParamWidget::valueChanged(const QString& value)
{
    _par->setNewValue(value.latin1());
}

void ChoiceParamWidget::updateView()
{
    setItem(_par->asString().c_str());
    emit activated(currentItem());
}

/*
 *  Set current item to that matching string.
 *  If the string is missing, then add it.
 */

void ChoiceParamWidget::setItem(const char* string)
{
    QString str(string);

    int n = count();
    int i = 0;

    while(i<n && !(str == text(i)))
        i++;

    if(i == n)
        insertItem(string);

    setCurrentItem(i);
}
