/*****************************************************************************
 *
 *  ParamWidget.cc                              XMM Science Analysis Subsystem
 *
 *  Widgets for editting parameters
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: ParamWidget.cc,v 1.12 2002/05/21 16:39:44 jbakker Exp $
 *
 *****************************************************************************/

#include "Parameter.h"         // Application headers
#include "ParamWidget.h"
#include "BoolParamWidget.h"
#include "IntParamWidget.h"
#include "RealParamWidget.h"
#include "AngleParamWidget.h"
#include "TimeParamWidget.h"
#include "StringParamWidget.h"
#include "ChoiceParamWidget.h"
#include "FileNameParamWidget.h"
#include "BoolListParamWidget.h"
#include "IntListParamWidget.h"
#include "RealListParamWidget.h"
#include "AngleListParamWidget.h"
#include "TimeListParamWidget.h"
#include "SpecialStringParamWidgets.h"
#include "ChoiceChildParameters.h"
#include <errstr.h>

#include <iostream>          // C++ headers
#include <string>
#include <qwidget.h>

class BoolParameter;


//================================================================
//  Abstract class ParamWidget
//================================================================

/*** Virtual constructor ***/

QWidget* ParamWidget::makeWidget(Parameter* param, QWidget* parent, 
				 const char* label)
{
  // make simple widgets:
  QWidget* w=0;
  int nChildren=param->children().size();

  switch(param->getType()) {

  case Parameter::Bool: {
    if (nChildren) w=new ChoiceParamWidget(param,parent);
    else           w=new BoolParamWidget((BoolParameter*)param, parent, label);
    break;
  }
  case Parameter::Int: {
    w=new IntParamWidget((IntParameter*)param, parent);
    break;
  }
  case Parameter::Real: {
    w=new RealParamWidget((RealParameter*)param, parent);
    break;
  }
  case Parameter::Angle: {
    w=new AngleParamWidget((AngleParameter*)param, parent);
    break;
  } 
  case Parameter::Time: {
    w=new TimeParamWidget((TimeParameter*)param, parent);
    break;
  }
  case Parameter::StringList:
  case Parameter::String: {
    if (nChildren) w=new ChoiceParamWidget(param,parent);
    else w=new ValEdit(param, parent); // TODO:?
    break;
  }
  case Parameter::FileName: {
    w=new FileNameParamWidget((FileNameParameter*)param, parent);
    break;
  }
  case Parameter::Directory: {
    w=new DirectoryParamWidget((DirectoryParameter*)param, parent);
    break;
  }
  case Parameter::DataSet: {
    w=new DataSetParamWidget((DataSetParameter*)param, parent);
    break;
  }
  case Parameter::DirOrDataSet: {
    w=new DirOrDataSetParamWidget((DirOrDataSetParameter*)param, parent);
    break;
  }
  case Parameter::DirOrFile: {
    w=new DirOrFileParamWidget((DirOrFileParameter*)param, parent);
    break;
  }
  case Parameter::Block: {
    w=new BlockParamWidget((BlockParameter*)param, parent);
    break;
  }
  case Parameter::Table: {
    w=new TableParamWidget((TableParameter*)param, parent);
    break;
  }
  case Parameter::Array: {
    w=new ArrayParamWidget((ArrayParameter*)param, parent);
    break;
  }
  case Parameter::Column: {
    w=new ColumnParamWidget((ColumnParameter*)param, parent);
    break;
  }
  case Parameter::BoolList: {
    w=new BoolListParamWidget((BoolListParameter*)param, parent);
    break;
  }
  case Parameter::IntList: {
    w=new IntListParamWidget((IntListParameter*)param, parent);
    break;
  }
  case Parameter::RealList: {
    w=new RealListParamWidget((RealListParameter*)param, parent);
    break;
  }
  case Parameter::AngleList: {
    w=new AngleListParamWidget((AngleListParameter*)param, parent);
    break;
  }
  case Parameter::TimeList: {
    w=new TimeListParamWidget((TimeListParameter*)param, parent);
    break;
  }
  case Parameter::FileNameList: { // TODO: make it popup!
    w=new ValEdit(param, parent); // TODO:?
    break;
  }
  case Parameter::DirectoryList: {
    w=new DirectoryListParamWidget((DirectoryListParameter*)param, parent);
    break;
  }
  case Parameter::DataSetList: {
    w=new DataSetListParamWidget((DataSetListParameter*)param, parent);
    break;
  }
  case Parameter::BlockList: {
    w=new BlockListParamWidget((BlockListParameter*)param, parent);
    break;
  }
  case Parameter::TableList: {
    w=new TableListParamWidget((TableListParameter*)param, parent);
    break;
  }
  case Parameter::ArrayList: {
    w=new ArrayListParamWidget((ArrayListParameter*)param, parent);
    break;
  }
  case Parameter::ColumnList: {
    w=new ColumnListParamWidget((ColumnListParameter*)param, parent);
    break;
  }
  default:
    errstr << "Parameter '" << param->name()
	   << "' has unknown type '" << param->getTypeName() << '\''
	   << Sas::warning(string("UnknownParType"));
    break;
  }
  return w;
}

