/*****************************************************************************
 *
 *  PopupParamWidget.cc                         XMM Science Analysis Subsystem
 *
 *  String widget which pops up a browser dialog
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: PopupParamWidget.cc,v 1.11 2002/05/21 16:39:44 jbakker Exp $
 *
 *****************************************************************************/

#include "PopupParamWidget.h"      // Application headers
#include "ValEdit.h"
#include "Parameter.h"
#include "IconLibrary.h"

#include <qtooltip.h>
#include <qpushbutton.h>
#include <qwidget.h>

//================================================================
//  Abstract class PopupParamWidget
//================================================================

PopupParamWidget::PopupParamWidget(Parameter* par, QWidget* parent)
  : QWidget(parent), _par(par)
{
    _itype = DalListViewable::None;
    _edit = new ValEdit(_par,this);

    _button = new QPushButton(this);
    _button->setAutoDefault(false);

    const QPixmap* pm=&IconLibrary::instance()->icon("FolderClosed.xpm");
    if (pm) _button->setPixmap(*pm);
    else _button->setText("..");
    
    QString prompt("Select ");
    if (_par->size() > -1) prompt+="(one or more) ";
    prompt+=_par->getTypeName();
    prompt+="...";

    QToolTip::add(_button,prompt);
    connect(_button, SIGNAL(clicked()),this, SLOT(popup()));

    updateView();
}

PopupParamWidget::~PopupParamWidget()
{
}

void PopupParamWidget::resizeEvent(QResizeEvent*)
{
    int w = width();
    int h = height();
    int bw = _button->sizeHint().width();
    
    _edit->setGeometry(0,0,w-bw,h);
    _button->setGeometry(w-bw,0,bw,h);
}

void PopupParamWidget::setEnabled(bool enable)
{
    _edit->setEnabled(enable);
    _button->setEnabled(enable);
}

void PopupParamWidget::popup()
{
  QString got=lookUp();
  if (got.isNull()) return;
  
  QString old=_edit->text();
  _edit->setText(got);
  if (!_edit->evaluate()) _edit->setText(old);
}
