// -*-C++-*-
//
// File:      TimeParamWidget.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Fri May  3 15:54:07 MEST 2002

#include "TimeParamWidget.h"
#include "FormattedTimeParamWidget.h"
#include "TimeParameter.h"
#include "TimeFormatter.h"

#include <qlayout.h>               // Qt headers
#include <qcombobox.h>

TimeParamWidget::TimeParamWidget(TimeParameter* par,QWidget* parent, const char* name) : QWidget(parent,name)
{
  _text=new FormattedTimeParamWidget(par,this);
  par->addView(this);

  _mode = new QComboBox(false,this,"TimeMode");
  _mode->insertItem("MRT",0);
  _mode->insertItem("JD",1);
  _mode->insertItem("MJD",2);
  _mode->insertItem("CAL",3);
  _mode->insertItem("FITS",4);
  
  // layout
  QHBoxLayout* box = new QHBoxLayout(this,0,-1,"TimeParamWidgetLayout");
  box->addWidget(_text);
  box->addWidget(_mode);
  box->addStretch(1);

  // update parameter representation
  updateView();

  // signal-slots
  connect(_mode,SIGNAL(activated(int)),
	  this,SLOT(activateMode(int)));
}

TimeParamWidget::~TimeParamWidget()
{
  _text->parameter()->deleteView(this);
}


/* triggerd by combo box */
void TimeParamWidget::activateMode(int id)
{
  TimeFormatter::TimeMode m = TimeFormatter::MRT;

  switch (id) {
  case 0: m = TimeFormatter::MRT ; break;
  case 1: m = TimeFormatter::JD  ; break;
  case 2: m = TimeFormatter::MJD ; break;
  case 3: m = TimeFormatter::CAL ; break;
  case 4: m = TimeFormatter::FITS; break;
  default: break;
  }
  ((TimeParameter*)(_text->parameter()))->setMode(m);
}

/*** Set the mode (Degrees, DMS or HMS) ***/
void TimeParamWidget::updateView()
{
  TimeFormatter::TimeMode m=
    ((TimeParameter*)(_text->parameter()))->getMode();

  int id=_mode->currentItem();
  switch(m) {
  case TimeFormatter::MRT: id=0; break;
  case TimeFormatter::JD: id=1; break;
  case TimeFormatter::MJD: id=2; break;
  case TimeFormatter::CAL: id=3; break;
  case TimeFormatter::FITS: id=4; break;
  default: break;
  }
  _mode->setCurrentItem(id);
}
