#include "ValEdit.h"
#include "Parameter.h"
#include "ExceptionErrorHandler.h"
#include "Error.h"
#include <qtooltip.h>
#include <iostream>


ErrorHandler* ValEdit::localHandler=0;

ValEdit::ValEdit(Parameter* p,QWidget* parent, const char* name) 
  : QLineEdit(parent,name),
    _parameter(p),
    timerId(0),
    oldText("")
{
  if (!localHandler) localHandler=new ExceptionErrorHandler;


  if (_parameter) {
    _parameter->addView(this);
    string prompt     = _parameter->prompt();
    if(prompt.length()>0)
      QToolTip::add(this,prompt.c_str());
   
    // enforces validation in the widget that has the focus.
    connect(this, SIGNAL(textChanged(const QString& )), this, SLOT(evaluateWidget()));
    // enforces validation when the widget lost the focus (when you click on Run/OK button)
    connect(this, SIGNAL(lostFocus()), this, SLOT(evaluateLostFocus()));

      updateView();
  }
}


ValEdit::~ValEdit()
{
  if (_parameter) _parameter->deleteView(this);
}

bool ValEdit::validateText()
{
  QString newText=text();
  if (newText == oldText) 
    return true;
  
  return _parameter->setNewValue(newText.latin1());
}

void ValEdit::updateView()
{
  QString newText=_parameter->asString().c_str();
  if (newText == oldText) return;

  oldText=newText;
  setText(oldText);
}

// enforces validation in the widget that has the focus.
void  ValEdit::evaluateWidget()
{

  intCursorPosition = cursorPosition();
    
  if (!evaluate()) {
    if (!timerId) timerId=startTimer(1);
  }
  
  //When the evaluate function is exectued (everytime the text changes)
  //the cursor position goes to the end of the text, which is annoying.
  //Now, after the evaluate function is executed, we set the cursor position
  //in the same place.
  try {
    setCursorPosition(intCursorPosition);
  }
  catch(...) { }

}

// enforces validation when the widget lost the focus (when you click on Run/OK button)
void ValEdit::evaluateLostFocus()
{
  
 if (!evaluate()) {
    if (!timerId) timerId=startTimer(1);
  }  
 
}


bool ValEdit::evaluate()
{
  ErrorHandler* oldHandler=errHandler.handler(localHandler);
  bool ok=false;

  try {
    ok=validateText();
  }
  catch(...) {
    ok=false;
  }
  errHandler.handler(oldHandler);
  return ok;
}

//
void ValEdit::timerEvent (QTimerEvent * e) 
{
  if (timerId && e->timerId() == timerId) {
    killTimer(timerId);
    timerId=0;
    std::cerr << '\a' << std::flush;
    blockSignals(true);
    setSelection(0,text().length());
    blockSignals(false);
    setFocus();
  }
  else QLineEdit::timerEvent(e);
}

/*
  Here we check that
 */
void ValEdit::focusOutEvent ( QFocusEvent * e) 
{
  if ((e->lostFocus() && e->reason() != QFocusEvent::ActiveWindow))  {
 
    if (!evaluate()) {
      if (!timerId) timerId=startTimer(1);
    }
  }
  
  QLineEdit::focusOutEvent(e);
  
}

void ValEdit::keyPressEvent(QKeyEvent* e)
{
  
  if ( e->key() == Key_Enter || e->key() == Key_Return ) {
    if (!evaluate()) {
      if (!timerId) timerId=startTimer(1);
    }
    else {
      QLineEdit::keyPressEvent(e);
    }
  }
  else
    QLineEdit::keyPressEvent(e);
  
}
void ValEdit::leaveEvent(QEvent* )
{
  if (!evaluate()) {
    if (!timerId) timerId=startTimer(1);
  }
}



