/****************************************************************************
 *
 *  OnDemandScrollView.cc                      XMM Science Analysis Subsystem
 *
 *  On-demand scroll-bars when widget exceeds a certain size
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: OnDemandScrollView.cc,v 1.4 2002/09/12 14:07:12 jbakker Exp $
 *
 *****************************************************************************/

#include "OnDemandScrollView.h"      // Application headers

#include <iostream>                // C++ headers

#include <qscrollview.h>             // Qt headers
#include <qwidget.h>
#include <qlayout.h>


//================================================================
//  Class OnDemandScrollView
//================================================================

OnDemandScrollView::OnDemandScrollView(QWidget *parent, const char *name)
   : QScrollView(parent, name)
{
    _maxWidth  = 3000;
    _maxHeight = 3000;
}

/*
 *  Return a preferred size which is just large enough to accomodate the 
 *  contents, without requiring scroll-bars. This can be restricted by setting
 *  a maximumPreferredSize, so that scroll-bars appear if the scroll view
 *  gets too large.
 */

QSize OnDemandScrollView::sizeHint() const
{
    int barWidth = horizontalScrollBar()->sizeHint().height();

    int maxWidth  = _maxWidth - barWidth;
    int maxHeight = _maxHeight - barWidth;

    int h = _contents->height();
    int w = _contents->width(); 

    //  Allow for the width of the scroll-bars

    if(h > maxHeight && w > maxWidth)
    {
        w += barWidth;
	h += barWidth;
    }
    else if(h > maxHeight)
        w += barWidth;
    else if(w > maxWidth)
        h += barWidth;

    if(h > maxHeight + barWidth)
        h = maxHeight + barWidth;

    if(w > maxWidth + barWidth)
        w = maxWidth + barWidth;

    // Allow for the width of the frame
    
    int fw = frameWidth() * 2;

    return QSize(w + fw, h + fw);
}

QSize OnDemandScrollView::minimumSizeHint() const
{
    return QSize(_minSize,_minSize);
}

void OnDemandScrollView::setMaximumPreferredWidth(int width)
{
    _maxWidth = width;
}

void OnDemandScrollView::setMaximumPreferredHeight(int height)
{
    _maxHeight = height;
}

void OnDemandScrollView::setMaximumPreferredSize(const QSize& size)
{
    _maxWidth  = size.width();
    _maxHeight = size.height();
}

void OnDemandScrollView::setMaximumPreferredSize(int width, int height)
{
    _maxWidth  = width;
    _maxHeight = height;
}

void OnDemandScrollView::setContents(QWidget* w)
{
    _contents = w;
    if(w->layout())
        w->layout()->setResizeMode(QLayout::Fixed);
    addChild(w);

    viewport()->setBackgroundColor(w->backgroundColor());
}

