/*****************************************************************************
 *
 *  testAlertDialog.cc                          XMM Science Analysis Subsystem
 *
 *  Test program for AlertDialog
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: testAlertDialog.cc,v 1.3 2001/05/10 13:03:53 jbakker Exp $
 *
 *****************************************************************************/

#include "AlertDialog.h"
#include "testAlertDialog.h"

#include <iostream>

#include <qapplication.h>
#include <qlayout.h>
#include <qpushbutton.h>
#include <qlayout.h>


//================================================================
//  Class Demo
//================================================================

/*** Constructor ***/

Demo::Demo(QWidget *parent, const char *name)
    : QWidget( parent, name )
{
    QPushButton* alert0Button = new QPushButton("Zero",this);
    connect(alert0Button,SIGNAL(clicked()),SLOT(alert0()));
    alert0Button->setFixedSize(70,20);

    QPushButton* alert1Button = new QPushButton("One",this);
    connect(alert1Button,SIGNAL(clicked()),SLOT(alert1()));
    alert1Button->setFixedSize(70,20);

    QPushButton* alert2Button = new QPushButton("Two",this);
    connect(alert2Button,SIGNAL(clicked()),SLOT(alert2()));
    alert2Button->setFixedSize(70,20);

    QPushButton* alert3Button = new QPushButton("Three",this);
    connect(alert3Button,SIGNAL(clicked()),SLOT(alert3()));
    alert3Button->setFixedSize(70,20);

    QPushButton* resetButton = new QPushButton("Reset",this);
    connect(resetButton,SIGNAL(clicked()),SLOT(reset()));
    resetButton->setFixedSize(70,20);

    QPushButton* quitButton = new QPushButton("Quit",this);
    connect(quitButton,SIGNAL(clicked()),qApp,SLOT(quit()));
    quitButton->setFixedSize(70,20);


    /*** Manage the geometry ***/

    QBoxLayout* vbox = new QVBoxLayout(this,10);

    vbox->addWidget(alert0Button,0);
    vbox->addStretch(1);
    vbox->addWidget(alert1Button,0);
    vbox->addStretch(1);
    vbox->addWidget(alert2Button,0);
    vbox->addStretch(1);
    vbox->addWidget(alert3Button,0);
    vbox->addStretch(1);
    vbox->addWidget(resetButton,0);
    vbox->addStretch(1);
    vbox->addWidget(quitButton,0);
}

/*
 *  Test simple message with no icon, code, title, etc
 */

void Demo::alert0()
{
    AlertDialog::alert(this,                 // parent
		       0,                    // title
		       "hello",              // message
		       QMessageBox::NoIcon,  // type
		       0);                   // code
}

/*
 *  Test long message requiring horizontal scroll bar, with unique code
 *  and dialog title.
 */

void Demo::alert1()
{
    AlertDialog::alert(this,
		       "Warning: Task foo",
		       "hello world One two three four five six seven eight"
		       "nine ten eleven twelve thirteen fourteen fifteen",
		       QMessageBox::Information,
		       "One");
}

/*
 *  Test multi-line message with unique code and no dialog title
 */

void Demo::alert2()
{
    AlertDialog::alert(this,
		       0,
		       "The quick\nbrown fox\njumps over\nthe lazy dog.",
		       QMessageBox::Warning,
		       "Two");
}

/*
 *  Test short message without unique code, but with dialog title
 */

void Demo::alert3()
{
    AlertDialog::alert(this,
		       "Foo",
		       "hello world",
 		       QMessageBox::Critical,
		       0);
}

/*** Reset "don't show again" status ***/

void Demo::reset()
{
    AlertDialog::reset();
}


//================================================================
//  Main program
//================================================================

int main(int argc, char **argv)
{
    QApplication app(argc, argv);
    Demo mainWidget;
    app.setMainWidget(&mainWidget);

    mainWidget.show();
    return app.exec();
}
