/*****************************************************************************
 *
 *  LogPane.h                                   XMM Science Analysis Subsystem
 *
 *  Scrolling pane to display log
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: LogPane.h,v 1.4 2002/09/12 14:07:12 jbakker Exp $
 *
 *****************************************************************************/

#ifndef LOGPANE_H
#define LOGPANE_H

#include "Logger.h"             // Application headers

#include <qmultilineedit.h>     // Qt headers

#include <string>               // C++ headers
#include <fstream>

class QWidget;
class QPrinter;
class QStatusBar;


//================================================================
//  Class LogPane
//
//  Responsibilities:
//    - displaying log in a scrolling pane
//    - copying log entries to a log file
//    - extracting an executable script from the log
//    - printing the log
//
//  LogPane is a scrolling pane for displaying log entries.
//  It implements the LogHandler interface, so that it can be
//  registered to receive log messages.
//
//  If a log file is specified, log entries are copied to the 
//  file. The log file is closed when the LogPane is deleted by
//  its parent QWidget.
//
//  Example:
//      logPane = new LogPane(this);
//      logPane->setLogFile("log");
//      Logger::registerLogHandler(logPane);
//      ...
//      Logger::write("hello");
//
//================================================================

class LogPane : public QMultiLineEdit, public Logger
{
public:
    LogPane(QWidget* parent);
    ~LogPane();

    void setLogFile(const string& logFileName);
    void saveAsScript();
    void print(QPrinter* printer, QStatusBar* statusBar);

    void writeToLog(const string& message);

private:
    // Disable copy constructor and assignment
    LogPane(const LogPane&) 
      : QMultiLineEdit(), Logger() {}
    LogPane& operator=(const LogPane&) { return *this; }

    void makeExecutable(const string&) const;

    // Member data
    ofstream* _logs;
    string    _logfile;
};

#endif
