/*****************************************************************************
 *
 *  Logger.h                                    XMM Science Analysis Subsystem
 *
 *  Logger class
 *
 *  (c) 1998 ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: Logger.h,v 1.5 2001/05/10 13:03:54 jbakker Exp $
 *
 *****************************************************************************/

#ifndef LOGGER_H
#define LOGGER_H

#include <iostream>
#include <string>


//================================================================
//  Interface LogHandler
//================================================================

class LogHandler
{
public:
    virtual void writeToLog(const string& s) = 0;
};


//================================================================
//  Class Logger
//
//  Responsibilities:
//    - registers a LogHandler
//    - forwards messages to LogHandler
//
//================================================================

class Logger : public LogHandler
{
public:
    // Write message to log
    static void write(const string& s)
    {
        if(!_log)
	    cout << s << endl;
	else
	    _log->writeToLog(s);
    }
 
    static void writeCommand(const string& s)
    {
        if(!_log)
	    cout << s << endl;
	else
	    _log->writeToLog(string("@@ ") + s);
    }
 
    // Register a LogHandler
    static void registerLogHandler(LogHandler* h) { _log = h; }

private:
    // Pointer to currently-registered handler
    static LogHandler* _log;
};

#endif
