/*****************************************************************************
 *
 *  SasErrorHandler.cc                          XMM Science Analysis Subsystem
 *
 *  Error handler for the SAS GUI
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: SasErrorHandler.cc,v 1.5 2009/08/31 15:17:17 aibarra Exp $
 *
 *****************************************************************************/

#include <iostream>
#include <sstream>

#include <qapplication.h>
#include <qmessagebox.h>

#include "SasErrorHandler.h"
#include "Logger.h"
#include "AlertDialog.h"
/* AI gcc4 porting
 *  error: ‘::exit’ has not been declared => #include <cstdlib>
 */
#include <cstdlib>
#define appName "SAS"
                                // TEMPORARY


//================================================================
//  Class SasErrorHandler
//================================================================

/*** Constructor ***/

SasErrorHandler::SasErrorHandler()
{
    _verbosity = Msg::Silent;
}


/*** Assignment operator ***/

ErrorHandler& SasErrorHandler::operator=(const ErrorHandler& h)
{
    _name = h.name();
    _verbosity = h.verbosity();
    return *this;
}


//----------------------------------------
//  Message handling
//----------------------------------------

/*** Report a fatal error ***/

void SasErrorHandler::fatal(Code code, const string& message)
{
    ostringstream ostr;
    ostr << "** Fatal: " << code << ": " << message;
    Logger::write(ostr.str());

    AlertDialog::alert(qApp->mainWidget(),
                       appName,
                       message.c_str(),
                       QMessageBox::Critical);
    ::exit(1);
}


/*** Report a non-fatal error ***/

void SasErrorHandler::error(Code code, const string& message)
{
    ostringstream ostr;
    ostr << "** Error: " << code << ": " << message;
    Logger::write(ostr.str());

    AlertDialog::alert(qApp->mainWidget(),
                       appName,
                       message.c_str(),
                       QMessageBox::Critical);
}


/*** Report a warning ***/

void SasErrorHandler::warning(Code code, const string& message)
{
    ostringstream ostr;
    ostr << "** Warning: " << code << ": " << message;
    Logger::write(ostr.str());

    AlertDialog::alert(qApp->mainWidget(),
                       appName,
                       message.c_str(),
                       QMessageBox::Warning);
}


/*** Report a message ***/

void SasErrorHandler::message(Layer layer, Verbosity level, const string& message)
{
    if(verbosity(layer) >= level)
    {
	Logger::write(message);
    }
}


/*** Set name of application ***/

void SasErrorHandler::name(const string& name)
{
    _name = name;
}


/*** Get name of application ***/

const string& SasErrorHandler::name() const
{
    return _name;
}


//----------------------------------------
//  Verbosity control
//----------------------------------------

void SasErrorHandler::verbosity(Verbosity level)
{
    _verbosity = level;
}

Msg::Verbosity SasErrorHandler::verbosity() const
{
    return _verbosity;
}

Msg::Verbosity SasErrorHandler::verbosity(Layer layer) const
{
    return _verbosity - int(layer);
}
