/*****************************************************************************
 *
 *  SasErrorHandler.h                           XMM Science Analysis Subsystem
 *
 *  Error handler for the SAS GUI
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: SasErrorHandler.h,v 1.3 2000/10/27 16:52:24 jbakker Exp $
 *
 *****************************************************************************/

#ifndef SASERRORHANDLER_H
#define SASERRORHANDLER_H

#include "ErrorHandler.h"

#include <string>


//================================================================
//  Class SasErrorHandler
//
//  Responsibilities:
//  - acts as registered ErrorHandler
//  - controls message verbosity
//  - displays dialogs for warnings and errors
//  - forwards messages, warnings and errors to Logger
//
//================================================================

class SasErrorHandler : public ErrorHandler
{
public:
    // Constructor
    SasErrorHandler();

    // Message handling
    void fatal(Code code, const string& message);
    void error(Code code, const string& message);
    void warning(Code code, const string& message);
    void message(Layer layer, Verbosity level, const string& message);

    void tryExternal(ExternRoutine r) { r();}
private:
    // Set/get name of application
    void          name(const string& name);
    const string& name() const;

    // Control message verbosity
    void      verbosity(Verbosity level);
    Verbosity verbosity() const;
    Verbosity verbosity(Layer layer) const;

    // Assignment operator
    ErrorHandler& operator=(const ErrorHandler& h);

    // Member data
    Verbosity       _verbosity;
    string          _name;
};

#endif
