/*****************************************************************************
 *
 *  TaskManager.h                               XMM Science Analysis Subsystem
 *
 *  Controller to manage execution of tasks
 *
 *  (c) 1999 ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: TaskManager.h,v 1.6 2000/10/24 09:36:59 ulammers Exp $
 *
 *****************************************************************************/

#ifndef TASKMANAGER_H
#define TASKMANAGER_H

#include "SasTask.h"              // Application headers
#include "GuiPreferences.h"

#include <list>                // C++ headers

#include <qobject.h>           // Qt headers


//================================================================
//  Class TaskManager
//
//  Responsibilities:
//    - displaying parameter dialog
//    - running tasks
//    - queueing tasks
//    - killing tasks
//
//  The TaskManager is used to control the running of tasks. The user
//  is prompted to edit parameter values and can then start the task.
//  If a task is already running, the user is given the option of
//  running the task, or queueing it.
//
//  Example:
//      _taskManager = new TaskManager(this);
//      _taskManager->setPreferences(_preferences);
//      connect(_taskManager,SIGNAL(enableKill(bool)),SLOT(enableKill(bool)));
//      connect(_taskManager,SIGNAL(transientMessage(const char*)),
//	    SLOT(transientessage(const char*)));
//      ...
//      _taskManager->editParam("foo");
//
//================================================================

class TaskManager : public QObject
{
    Q_OBJECT

public:
    TaskManager(QWidget* parent);
    ~TaskManager();

    void editParam(const char* taskName);
    void killLastTask();
    void setPreferences(GuiPreferences* preferences);
    bool tasksRunning();

signals:
    void enableKill(bool enable);
    void transientMessage(const char* text);

private slots:
    void taskDone(int exitCode, SasTask* task);

private:
    // SasTask control
    void runTask(SasTask* task);
    void runQueuedTask();
    void showInfo(const string& text);

    // Member data
    list<SasTask*>  _tasks;
    list<SasTask*>  _queue;
    QWidget*        _parent;
    GuiPreferences* _preferences;
};

#endif
